![Databricks Labs Lakebridge](/docs/lakebridge/static/img/lakebridge-lockup-white-background.svg)
===============
by [Databricks Labs](https://www.databricks.com/learn/labs)

[![build](https://github.com/databrickslabs/lakebridge/actions/workflows/push.yml/badge.svg)](https://github.com/databrickslabs/remorph/actions/workflows/push.yml)
![PyPI - Downloads](https://img.shields.io/pypi/dm/databricks-labs-remorph?cacheSeconds=3600)

-----
Documentation is available at: https://databrickslabs.github.io/lakebridge/

Contribution
------------

Please see the contribution guidance [here](docs/lakebridge/docs/dev/contributing.md) on how to contribute to the project (build, test, and submit a PR).

Project Support
---------------

Please note that this project is provided for your exploration only and is not formally supported by Databricks with Service Level Agreements (SLAs). They are provided AS-IS, and we do not make any guarantees. Please do not submit a support ticket relating to any issues arising from the use of this project.

Any issues discovered through the use of this project should be filed as [GitHub Issues](https://github.com/databrickslabs/lakebridge/issues/) on this repository. They will be reviewed as time permits, but no formal SLAs for support exist.
